@@ -6,16 +6,21 @@ test_that("We can register & retrieve content from the remote API", {
 
   ## A zenodo URL will be stable
   url <- "https://zenodo.org/record/3678928/files/vostok.icecore.co2"
-  ## or not?
+  ## or not.... use KNB
   url <- "https://knb.ecoinformatics.org/knb/d1/mn/v2/object/ess-dive-457358fdc81d3a5-20180726T203952542"
+  ## Or use this zenodo download url:
+  
+  
+  ## hash-archive.org may timeout more often these days...
+  hash_archive <- "https://hash-archive.thelio.carlboettiger.info"
+  
+  id <- register(url,hash_archive)
+  
   
-  id <- register(
-    url,
-    "https://hash-archive.org")
   expect_is(id, "character")
 
   
-  df <- query(id, registries = "https://hash-archive.org")
+  df <- query(id, registries = hash_archive)
   expect_is(df, "data.frame")
   expect_true(dim(df)[1] > 1)
 
